@@ -12,6 +12,10 @@ magrittr::`%<>%`
 #' @importFrom magrittr "%$%"
 magrittr::`%$%`
 
+#' @export
+#' @importFrom magrittr "%T>%"
+magrittr::`%T>%`
+
 #' @export
 #' @importFrom tibble tibble
 tibble::tibble
